System prompt injection based on turn count and token thresholds.
Structs
- System
Injector - Injects system prompt content based on turn or token thresholds.
Enums
- Injection
Trigger - Trigger condition for a
SystemInjectorrule.
System prompt injection based on turn count and token thresholds.
SystemInjector rule.