pub struct SlidingWindow { /* private fields */ }Expand description
Sliding window context strategy.
When context exceeds the limit, drops the oldest messages (keeping the first message, which is typically the initial user message).
Implementations
Sourceimpl SlidingWindow
impl SlidingWindow
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new sliding window strategy.
chars_per_token controls the token estimation granularity
(default: 4 chars per token).
Sourcepub fn with_ratio(chars_per_token: usize) -> Self
pub fn with_ratio(chars_per_token: usize) -> Self
Create with a custom chars-per-token ratio.